@@ -71,7 +71,7 @@ def is_table_stale(
 
 def is_workflow_stale(
     cur: Cursor,
-    table: str,
+    table_name: str,
     max_hours_behind: int = 24
 ):
     """returns true if last workflow did not succeed or is too old"""
@@ -92,18 +92,18 @@ def is_workflow_stale(
                 osddm_report_repos.mx_rep_wflow_run c
                 on b.workflow_id = c.workflow_id
             where
-                a.table_name = upper(:table)
+                a.table_name = upper(:table_name)
         )
         select * from t where t.rn = 1
         """,
-        table=table # type: ignore
+        table_name=table_name # type: ignore
     )
     try:
         row: tuple = cur.fetchone()[0] # type: ignore
         wflow_date: datetime = row[1]
         succeeded = bool(row[2])
     except (TypeError, IndexError) as exc:
-        raise Exception(f"Workflow with target {table} not found") from exc
+        raise Exception(f"Workflow with target {table_name} not found") from exc
     if not succeeded:
         return False
     return (datetime.today().date() - wflow_date.date()) >= timedelta(hours=max_hours_behind)
@@ -122,11 +122,14 @@ def update_table_from_sql(
     table: str,
     update_sql: str,
     bind_today: bool = True,
-    bind_name: str = "today",
+    bind_name: str = "etl_date",
     enable_logging: bool = True
 ):
     """basic update of table using provided sql
-    if bind_today is set then today() is bound to the :bind_name"""
+    if bind_today is set then today() is bound to variable :<bind_name>
+    (default: etl_date)
+    note that some bind names like "today", and "date" cannot be used.
+    """
     today = datetime.today()
     count_sql = f"select count(*) from {schema}.{table}"
     num_rows_old = cur.execute(count_sql).fetchone()[0] # type: ignore
